<?php
/*
 * Copyright (C) 2023 f.mignon Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

session_start();
if (!isset($_SESSION['authenticated']) || !$_SESSION['authenticated']) {
    header('Location: login.php');
    exit;
}

header("Content-Security-Policy: default-src 'self'; img-src 'self' data:; script-src 'self' 'unsafe-inline'; style-src 'self' 'unsafe-inline';");

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $baseDirectoryPath = __DIR__;
    $inputDirectoryPath = $_POST['directoryPath'] ?? '';

    $fullDirectoryPath = $baseDirectoryPath . '/' . $inputDirectoryPath;

    if (is_dir($fullDirectoryPath)) {
        $directoryPath = $fullDirectoryPath;
    } else {
        $directoryPath = null;
        $errorMsg = "Access to the specified directory is not allowed.";
    }
}

$imageExtensions = ['jpg', 'png', 'gif', 'jpeg', 'webp', 'svg', 'psd'];

include 'header.php';
?>

<h1>Select Directory</h1>
<form method="post" action="">
    <input type="text" name="directoryPath" placeholder="Enter directory path" value="<?php echo isset($inputDirectoryPath) ? htmlspecialchars($inputDirectoryPath) : ''; ?>" id="load-box">
    <button type="submit">画像一覧</button>
</form>

<div class="image-container-wrap"><div class="selector">
<label><input type="radio" name="deleteMode" value="single" checked> 個別削除</label>
<label><input type="radio" name="deleteMode" value="multiple"> 一括削除</label>    
<?php
if (isset($directoryPath)) {
    echo '<form action="" method="post">';
    echo '<input type="hidden" name="directoryPath" value="' . htmlspecialchars($inputDirectoryPath) . '">';  // この行を追加
    echo '<label for="sortOrder">並び替え: </label>';
    echo '<select name="sortOrder" id="sortOrder" onchange="this.form.submit()">';
    echo '<option value="name"' . ($_POST['sortOrder'] === 'name' ? ' selected' : '') . '>名前順</option>';
    echo '<option value="size"' . ($_POST['sortOrder'] === 'size' ? ' selected' : '') . '>サイズ順</option>';
    echo '</select>';
    echo '</form></div>';

    echo '<form action="delete.php" method="post" id="multiple-delete-form">';
    echo '<div class="image-container">';
    $files = scandir($directoryPath);
    $fileData = [];

    foreach ($files as $file) {
        $filePath = $directoryPath . '/' . $file;
        if (is_file($filePath) && exif_imagetype($filePath)) {
            $fileSize = filesize($filePath);
            $fileData[] = ['name' => $file, 'path' => $filePath, 'size' => $fileSize];
        }
    }

    $sortOrder = $_POST['sortOrder'] ?? 'name';
    usort($fileData, function ($a, $b) use ($sortOrder) {
        return $sortOrder === 'size' ? $b['size'] - $a['size'] : strcmp($a['name'], $b['name']);
    });

    foreach ($fileData as $data) {
        $filePath = $data['path'];
        list($width, $height) = getimagesize($filePath);
        $fileSizeInKB = $data['size'] / 1024;

        if ($fileSizeInKB >= 1024) {
            $fileSize = round($fileSizeInKB / 1024, 2) . ' MB';
        } else {
            $fileSize = round($fileSizeInKB, 2) . ' KB';
        }

        echo '<div class="image-item">';
        echo '<img src="' . $inputDirectoryPath . '/' . $data['name'] . '" alt="' . $data['name'] . '">';
        echo '<p class="image-name" data-src="' . $inputDirectoryPath . '/' . $data['name']  . '">' . $data['name']  . '</p>';
        echo '<p>Size: ' . $width . 'x' . $height . '</p>';
        echo '<p>File Size: ' . $fileSize . '</p>';
        echo '<button type="button" class="single-delete" data-path="' . $filePath . '">削除</button>';
        echo '<input type="checkbox" class="multiple-delete" name="imagePaths[]" value="' . $filePath . '">';
        echo '</div>';
    }

    echo '</div>';
    echo '<button type="submit" id="bulk-delete-button">一括削除</button>';
    echo '</form>';
} elseif (isset($errorMsg)) {
    echo "<p>$errorMsg</p>";
}
?>

</div>

<script>
document.addEventListener("DOMContentLoaded", function() {
    const singleDeleteButtons = document.querySelectorAll('.single-delete');
    const multipleDeleteCheckboxes = document.querySelectorAll('.multiple-delete');
    const deleteModeRadios = document.querySelectorAll('input[name="deleteMode"]');
    const multipleDeleteForm = document.getElementById('multiple-delete-form');  // 一括削除用のformを取得

    function updateDeleteMode() {
        const mode = document.querySelector('input[name="deleteMode"]:checked').value;
        const bulkDeleteButton = document.getElementById('bulk-delete-button');

        if (mode === 'single') {
            singleDeleteButtons.forEach(btn => btn.style.display = 'inline-block');
            multipleDeleteCheckboxes.forEach(cb => cb.style.display = 'none');
            bulkDeleteButton.style.display = 'none';
        } else {
            singleDeleteButtons.forEach(btn => btn.style.display = 'none');
            multipleDeleteCheckboxes.forEach(cb => cb.style.display = 'inline-block');
            bulkDeleteButton.style.display = 'inline-block';
        }
    }

    deleteModeRadios.forEach(radio => {
        radio.addEventListener('change', updateDeleteMode);
    });

    updateDeleteMode();

    singleDeleteButtons.forEach(button => {
        button.addEventListener('click', function() {
            const filePath = this.getAttribute('data-path');
            const parentDiv = this.closest('.image-item');

            fetch('delete.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json'
                },
                body: JSON.stringify({ filePaths: [filePath] })  // 配列として送信
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    alert('File deleted successfully');
                    if (parentDiv) {
                        parentDiv.remove();
                    }
                } else {
                    alert('Failed to delete file');
                }
            })
            .catch(error => {
                console.error('Error:', error);
            });
        });
    });

    // 一括削除の処理
    multipleDeleteForm.addEventListener('submit', function(e) {
        e.preventDefault();
        const selectedCheckboxes = document.querySelectorAll('.multiple-delete:checked');
        const filePaths = Array.from(selectedCheckboxes).map(cb => cb.value);

        fetch('delete.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({ filePaths: filePaths })  // 複数のfilePathを配列として送信
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                alert('Files deleted successfully');
                filePaths.forEach(path => {
                    const parentDiv = document.querySelector(`input[value="${path}"]`).closest('.image-item');
                    if (parentDiv) {
                        parentDiv.remove();
                    }
                });
            } else {
                alert('Failed to delete files');
            }
        })
        .catch(error => {
            console.error('Error:', error);
        });
    });

    // 画像をクリックしたときにチェックボックスがチェックされるように
    multipleDeleteCheckboxes.forEach(checkbox => {
        const parentDiv = checkbox.closest('.image-item');
        const img = parentDiv.querySelector('img');
        img.addEventListener('click', function() {
            checkbox.checked = !checkbox.checked;
        });
    });
});

</script>
<?php include 'footer.php'; ?>
