<?php
session_start();
$isSetup = file_exists('credentials.txt');
$hasError = false;
$errorMessage = '';

function validatePassword($password, $username) {
    if (strlen($password) < 8) {
        return 'パスワードは8文字以上である必要があります。';
    }
    if (!preg_match('/[a-z]/', $password) ||
        !preg_match('/[A-Z]/', $password) ||
        !preg_match('/[0-9]/', $password) ||
        !preg_match('/[\W_]/', $password)) {
        return 'パスワードには大文字、小文字、数字、特殊文字をそれぞれ1つ以上含める必要があります。';
    }
    if (strtolower($password) === strtolower($username)) {
        return 'ユーザー名とパスワードが一致しています。';
    }
    return '';
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = $_POST['username'] ?? '';
    $password = $_POST['password'] ?? '';

    if (empty($username) || empty($password)) {
        $hasError = true;
        $errorMessage = 'ユーザー名とパスワードは必須です。';
    } else {
        if (!$isSetup) {
            $validationResult = validatePassword($password, $username);
            if (!empty($validationResult)) {
                $hasError = true;
                $errorMessage = $validationResult;
            }
        }
    }
        if (!$hasError) {
            if ($isSetup) {
                $credentials = json_decode(file_get_contents('credentials.txt'), true);
                if (password_verify($password, $credentials['password']) && $username === $credentials['username']) {
                    $_SESSION['authenticated'] = true;
                    header('Location: index.php');
                    exit;
                } else {
                    $hasError = true;
                    $errorMessage = 'ユーザー名またはパスワードが間違っています。';
                }
            } else {
                $hashedPassword = password_hash($password, PASSWORD_DEFAULT);
                $credentials = [
                    'username' => $username,
                    'password' => $hashedPassword
                ];
                file_put_contents('credentials.txt', json_encode($credentials));
                header('Location: login.php');
            exit;
        }
    }
}
include 'header.php';
?>
<!DOCTYPE html>
<html>
<head>
    <title><?php echo $isSetup ? 'ログイン' : 'セットアップ'; ?></title>
</head>
<body>
<h2><?php echo $isSetup ? 'ログイン' : 'セットアップ'; ?></h2>
<?php if ($hasError): ?>
        <p style="color: red;"><?php echo $errorMessage; ?></p>
    <?php endif; ?>
    <form method="POST" action="" class="auth-form">
    <div class="form-group">
        <label for="username">ユーザーネーム:</label>
        <input type="text" name="username" id="username">
    </div>
    <div class="form-group">
        <label for="password">パスワード:</label>
        <input type="password" name="password" id="password">
    </div>
    <div class="form-group">
        <button type="submit"><?php echo $isSetup ? 'ログイン' : 'セットアップ'; ?></button>
    </div>
</form>
</body>
</html>
<?php include 'footer.php'; ?>